#!/usr/bin/env python

import os
import django

from tionix_scheduler.cmd.database.db_migrate import get_migrations_count
from tionix_scheduler.core.helpers import set_os_scheduler_settings
from tionix_scheduler.core.i18n import ugettext as _


def main(verbose=False):
    set_os_scheduler_settings()
    django.setup()

    from django.db import connection
    from django.db.migrations.recorder import MigrationRecorder
    from django.db.utils import ProgrammingError

    recorder = MigrationRecorder(connection)
    try:
        migrations_count = get_migrations_count(recorder)
    except ProgrammingError:
        migrations_count = 0
    except Exception as ex:
        if verbose:
            msg = _(u'Error while getting migrate versions: '
                    u'{0}').format(unicode(ex))
        else:
            msg = _(u'Unknown DB Error. Please contact your administrator.')
        return os.EX_SOFTWARE, msg

    return os.EX_OK, migrations_count
