#!/usr/bin/env python

import os
import logging
import django

from tionix_scheduler.core.helpers import set_os_scheduler_settings
from tionix_scheduler.core.i18n import ugettext as _


def get_version():
    # moved import inside function to avoid log messages before parsing args
    from tionix_scheduler.core.helpers import get_formatted_version
    return get_formatted_version()


def get_migrations_count(recorder):
    return recorder.migration_qs.count()


def migrate(*args):
    args_list = list(args)
    if '--verbose' in args_list:
        args_list = args_list.remove('--verbose')
    else:
        logging.disable(logging.WARN)

    from django.core.management import execute_from_command_line
    from django.db import connection
    from django.db.migrations.recorder import MigrationRecorder
    from django.db.utils import ProgrammingError

    recorder = MigrationRecorder(connection)
    try:
        old_migrations_count = get_migrations_count(recorder)
    except ProgrammingError:
        old_migrations_count = 0

    execute_from_command_line(args_list)
    new_migrations_count = get_migrations_count(recorder)

    if new_migrations_count == old_migrations_count:
        msg = _(u'No changes')
    else:
        msg = u'{0} -> {1}'.format(old_migrations_count, new_migrations_count)

    return os.EX_OK, msg


def main(migration=None, verbose=False):
    set_os_scheduler_settings()
    django.setup()

    migrate_args = None
    if isinstance(migration, basestring):
        migrate_args = migration.split()
        if len(migrate_args) != 2:
            return (
                os.EX_SOFTWARE,
                _(u'Invalid migration arguments: "{0}". '
                  u'Provide arguments as follows:'
                  u' "app_name migration_name"').format(migration)
            )

    # --traceback prevents calling sys.exit in execute_from_command_line
    # if CommandError exception raised
    args = [os.path.abspath(__file__), 'migrate', '--traceback']
    if migrate_args:
        args.extend(migrate_args)
    try:
        result = migrate(*args)
    except Exception as ex:
        if verbose:
            msg = _(u'Error while getting migrate versions: '
                    u'{0}').format(unicode(ex))
        else:
            msg = _(u'Unknown DB Error. Please contact your administrator.')
        return os.EX_SOFTWARE, msg

    return result
