# coding: utf-8

import argparse
import logging
import os
import sys
import pkg_resources

from pkg_resources import (DistributionNotFound, VersionConflict,
                           ContextualVersionConflict)

from tionix_scheduler.settings import BASE_DIR


logger = logging.getLogger(__name__)


def pretty_print(columns, items, out=None):
    """
    columns = [
        {
            'description': 'ID',
            'item_attr': 'id',
            'get_value': lambda x: unicode(x),
            'get_length': lambda x: len(unicode(x))
        }
    ]
    items = [
        {
            'id': 123
        }
    ]
    """

    out = out or sys.stdout

    def write(text):
        out.write(text.encode('utf-8'))

    for c in columns:
        c['max_length'] = len(c['description'])

    for item in items:
        for c in columns:
            c['max_length'] = max((
                c['max_length'],
                c.get(
                    'get_length', lambda x: len(unicode(x))
                )(getattr(item, c['item_attr']) if c['item_attr'] else item)))

    max_len_dots = sum((
        sum(c['max_length'] for c in columns),
        len(columns) * 3))

    write(u'-' * max_len_dots + u'\n'.encode())
    write(u' | '.join(
        c['description'].ljust(c['max_length']) for c in columns) + u'\n')
    write(u'-' * max_len_dots + u'\n')
    for item in items:
        # pylint: disable=unnecessary-lambda
        write(u' | '.join(
            c.get('get_value', lambda x: unicode(x))(
                getattr(item, c['item_attr']) if c['item_attr'] else item
            ).ljust(c['max_length'])
            for c in columns
        ) + u'\n')
    write(u'-' * max_len_dots + u'\n')


class Empty(object):
    def __init__(self, **kwargs):
        for k, v in kwargs.iteritems():
            setattr(self, k, v)


def get_package_name():
    dirs = reversed(os.path.abspath(BASE_DIR).split('/'))
    try:
        package_name = [dir_name.replace('_', '-') for dir_name in dirs
                        if 'tionix_' in dir_name][0]
    except IndexError:
        package_name = None
    return package_name


def get_version():
    """ Get installed package version """
    version = None
    package_name = get_package_name()
    try:
        version = pkg_resources.get_distribution(package_name).version
    except DistributionNotFound:
        logger.error(u'Package not found: {0}'.format(package_name))
    except (VersionConflict, ContextualVersionConflict) as err:
        logger.warning(u'Version conflict found: {0}'.format(err))
    return version


def get_formatted_version():
    return u"{0} {1}".format(
        get_package_name(), get_version()
    )


def create_argparser(*args, **kwargs):
    parser = argparse.ArgumentParser(*args, **kwargs)
    parser.add_argument(
        '--version', action='version', version=get_formatted_version())
    return parser


def set_os_scheduler_settings():
    os.environ['DJANGO_SETTINGS_MODULE'] = 'tionix_scheduler.settings'
