# coding: utf-8
import logging

from django.contrib.auth import get_user_model, REDIRECT_FIELD_NAME
from django.http import HttpResponseForbidden, HttpResponseRedirect
from tionix_client.os_clients.keystone_client import get_keystone_client

from tionix_scheduler.settings import KEYSTONE

from rest_framework.reverse import reverse

logger = logging.getLogger(__name__)


class KeystoneTokenMiddleware(object):

    def process_request(self, request):
        keystone_params = {}
        response = meta_token = username = password = None
        keystone_check = True

        login_url = reverse('rest_framework:login')
        admin_login_url = reverse('admin:login')

        if request.path in [login_url,
                            admin_login_url]:
            if request.method == "POST":
                params = {
                    'username': request.POST.get('username'),
                    'password': request.POST.get('password'),
                    'user_domain_name': request.POST.get('user_domain_name'),
                }
                keystone_params.update(params)
            else:
                keystone_check = False
        elif request.path in [reverse('rest_framework:logout'),
                              reverse('admin:logout')]:
            request.session.delete('auth_token')
            keystone_check = False
        else:
            meta_token = request.META.get('HTTP_X_AUTH_TOKEN')
            session_token = request.session.get('auth_token')
            keystone_params['token'] = meta_token or session_token
        if keystone_check:
            params = {
                'username': KEYSTONE['auth_user'],
                'password': KEYSTONE['auth_password'],
                'tenant': KEYSTONE['auth_tenant']
            }
            admin_client = get_keystone_client(**params)
            token = keystone_params.get('token')
            try:
                if token:
                    admin_client.tokens.validate(token)
                else:
                    keystone_client = get_keystone_client(**keystone_params)
                    token = keystone_client.auth_token
            except Exception as err:
                if meta_token:
                    response = HttpResponseForbidden(unicode(err))
                else:
                    redirect_to = request.POST.get(
                        REDIRECT_FIELD_NAME,
                        request.GET.get(REDIRECT_FIELD_NAME, '')
                    ) or request.path
                    if redirect_to != login_url:
                        login_url = '{0}?{1}={2}'.format(login_url,
                                                         REDIRECT_FIELD_NAME,
                                                         redirect_to)
                    response = HttpResponseRedirect(login_url)
            else:
                request.session['auth_token'] = token

                if username and password:
                    self._create_user(username, password)

        return response

    @staticmethod
    def _create_user(username, password):
        user_model = get_user_model()
        try:
            user = user_model.objects.filter(
                username=username
            ).order_by(
                '-id'
            )[0]
        except IndexError:
            user_model._default_manager.db_manager().create_superuser(
                username=username, password=password, email=None
            )
        else:
            if not user.check_password(password):
                user.set_password(password)
                user.save()
