# coding: utf-8

import logging.config

from collections import defaultdict
from tionix_scheduler.settings.settings_handler import (
    update_global_from_settings, update_module_settings)
from tionix_scheduler.settings.base import *
from tionix_scheduler.settings.celery import *

LOG_LEVEL = 'INFO'

LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'formatters': {
        'default': {
            'format': '%(asctime)s.%(msecs)03d %(process)d %(levelname)s '
                      '%(name)s [-] %(message)s',
            'datefmt': '%Y-%m-%d %H:%M:%S',
        },
    },
    'handlers': {
        'null': {
            'class': 'logging.NullHandler',
        },
        'console': {
            'class': 'logging.StreamHandler',
            'formatter': 'default',
        },
    },
    'loggers': {
        '': {
            'handlers': ['console'],
        },
        'tionix_scheduler': {
            'handlers': ['console']
        },
        'cmd': {
            'handlers': ['console'],
        },
        '__main__': {
            'handlers': ['console'],
        },
        'oslo_db': {
            'handlers': ['console'],
        },
        'requests.packages.urllib3.connectionpool': {
            'level': 'WARN',
            'handlers': ['null'],
        }
    }
}

logging.config.dictConfig(LOGGING)
logging.getLogger().setLevel(LOG_LEVEL)

base_config_path = '/etc/tionix/tionix.yaml'
module_config_path = '/etc/tionix/scheduler.yaml'

module_settings = defaultdict(dict)
gl = globals()

update_module_settings(
    module_settings, gl, module_config_path, base_config_path)

# Have to update log level before updating other variables for
# proper logger output
if module_settings['LOG_LEVEL']:
    logging.getLogger().setLevel(module_settings['LOG_LEVEL'])

update_global_from_settings(module_settings, gl)

DEBUG = LOG_LEVEL <= logging.DEBUG

logging.getLogger().setLevel(LOG_LEVEL)

BROKER_URL = (
    u"{broker_type}://{username}:{password}@{host}:{port}/{vhost}".format(
        **RABBIT_QUEUES))
