# coding: utf-8

import os
import unittest

import yaml

from tionix_scheduler import settings
from tionix_scheduler.core.i18n import ugettext as _


class ConfigFileTest(unittest.TestCase):
    def test_config_file_existence(self):
        """Check base and module configuration files.

        :lang:ru Проверка базового и модульного конфигурационного файла.
        """

        config_files = (settings.base_config_path, settings.module_config_path)
        for config_file in config_files:
            msg_exist = _(u'Config file "{0}" not found!').format(config_file)
            self.assertTrue(os.path.exists(config_file), msg=_(msg_exist))

        config = {}
        for conf_file in config_files:
            try:
                tmp_config = yaml.load(open(conf_file))
            except IOError:
                continue

            config.update(tmp_config)

        msg = _(u'Error. Invalid config file! '
                u'Check existence of section "{0}".')

        self.assertTrue('KEYSTONE' in config, msg=_(msg).format('KEYSTONE'))
        self.assertTrue('DB' in config, msg=_(msg).format('DB'))

    def test_apache_config_existence(self):
        """Check module apache configuration file.

        :lang:ru Проверка модульного конфигурационного файла Apache.
        """

        links_to_apache_config_file = (
            '/etc/apache2/conf-enabled/tionix-scheduler-dash.conf',
            '/etc/httpd2/conf/sites-enabled/tionix-scheduler-dash.conf',
            '/etc/httpd/conf/sites-enabled/tionix-scheduler-dash.conf',
        )
        apache_config_files = (
            '/etc/apache2/conf-available/tionix-scheduler-dash.conf',
            '/etc/httpd2/conf/sites-available/tionix-scheduler-dash.conf',
            '/etc/httpd/conf/sites-available/tionix-scheduler-dash.conf',
        )

        self.assertTrue(
            any(os.path.exists(link) for link in links_to_apache_config_file),
            msg=_(u'Error. Apache config file is not enabled.'))

        self.assertTrue(
            any(os.path.exists(path) for path in apache_config_files),
            msg=_(u'Configuration file for Apache not found.'))
