# coding: utf-8

import subprocess
import unittest

from tionix_scheduler.core.i18n import ugettext as _


class SupervisorConnectionTest(unittest.TestCase):

    supervisor_not_installed = _(u'Supervisor is not installed.')
    supervisor_not_launched = _(u'Supervisor is not launched.')
    correct_status = 'RUNNING'
    no_such_process = 'No such process'
    no_such_file = 'no such file'
    msg_is_not_configured = _(u'Scheduler {0} daemon is not configured.')
    msg_is_not_launched = _(u'Scheduler {0} daemon is not launched.')
    msg_root_required = _(u'Test requires root authentication')

    def test_beat_launched(self):
        """Verify that supervisor beat daemon is launched.

        :lang:ru Проверка работы beat-демона планировщика.
        """

        output = None
        cmd = ['supervisorctl', 'status', 'tionix-scheduler-beat']
        try:
            output = subprocess.check_output(cmd)
        except OSError:
            self.fail(_(self.supervisor_not_installed))
        except subprocess.CalledProcessError:
            self.skipTest(_(self.msg_root_required))

        self.assertNotIn(self.no_such_file, output,
                         msg=_(self.supervisor_not_launched))
        self.assertNotIn(self.no_such_process, output,
                         msg=_(self.msg_is_not_configured).format('beat'))
        self.assertIn(self.correct_status, output,
                      msg=_(self.msg_is_not_launched).format('beat'))

    def test_worker_launched(self):
        """Verify that supervisor worker daemon is launched.

        :lang:ru Проверка работы worker-демона планировщика.
        """

        output = None
        cmd = ['supervisorctl', 'status', 'tionix-scheduler-worker']
        try:
            output = subprocess.check_output(cmd)
        except OSError:
            self.fail(_(self.supervisor_not_installed))
        except subprocess.CalledProcessError:
            self.skipTest(_(self.msg_root_required))

        self.assertNotIn(self.no_such_file, output,
                         msg=_(self.supervisor_not_launched))
        self.assertNotIn(self.no_such_process, output,
                         msg=_(self.msg_is_not_configured).format('worker'))
        self.assertIn(self.correct_status, output,
                      msg=_(self.msg_is_not_launched).format('worker'))
