# coding: utf-8

"""
Timetable helper
"""

import logging

from keystoneclient.exceptions import Forbidden
from tionix_client.os_clients.keystone_client import get_keystone_client

from tionix_scheduler.settings import KEYSTONE


logger = logging.getLogger(__name__)


def get_user_info(request, tenant_id=None):

    username = ''
    tenants = []
    params = {
        'username': KEYSTONE['auth_user'],
        'password': KEYSTONE['auth_password'],
        'tenant': KEYSTONE['auth_tenant']
    }
    keystone_client = get_keystone_client(**params)

    token = request.session.get('auth_token')
    filter_tenants = request.GET.getlist('filter_tenants')
    all_tenants = request.GET.get('all_tenants', 'false')

    try:
        info = keystone_client.tokens.validate(token)
        if tenant_id is None or (all_tenants and
                                 all_tenants.lower() == 'true'):
            user_id = getattr(info, 'user_id', None)
            domain_id = getattr(info, 'domain_id', None)
            tenants = []
            try:
                tenants = keystone_client.projects.list(
                    user=user_id, domain=domain_id)
            except Forbidden:
                params.pop('tenant')
                params['domain'] = KEYSTONE['user_domain_name']
                try:
                    keystone_client = get_keystone_client(**params)
                    projects = keystone_client.projects.list(domain=domain_id)
                except Exception as e:
                    logger.error(e)
                else:
                    # list_user_projects is not allowed for cloud admin,
                    # so here we get user projects from role assignments
                    tenants = [
                        tenant for tenant in projects
                        if keystone_client.role_assignments.list(
                            user=user_id,
                            project=tenant.id
                        )
                    ]
            tenants = [tenant.id for tenant in tenants] or [tenant_id]
        else:
            tenants = [tenant_id]
        if filter_tenants:
            tenants = [tenant for tenant in tenants
                       if tenant in filter_tenants]
        username = getattr(info, 'username', None)
    except Exception as e:
        logger.error(unicode(e) or type(e))

    return username, tenants
