# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from django.db import models, migrations


def migrate_subject_type(apps, schema_editor):
    timetable = apps.get_model('timetable', 'TimeTable')

    admin_group = 'admin'
    vdi_group = 'vdi'
    project_group = 'project'
    identity_group = 'identity'

    hypervisor_type = 'hypervisor'
    instance_type = 'instance'
    volume_type = 'volume'
    project_type = 'project'

    group_map = {
        'admin_hypervisors': (admin_group, hypervisor_type),
        'admin_instances': (admin_group, instance_type),
        'vdi_instances': (vdi_group, instance_type),
        'admin_volumes': (admin_group, volume_type),
        'project_volumes': (project_group, volume_type),
        'identity_project': (identity_group, project_type),
        'vdi_project': (vdi_group, project_type),
    }

    for item in timetable.objects.all():
        subject_type = item.subject_type
        if subject_type in group_map:
            item.subject_group, item.subject_type = group_map[subject_type]
            item.save()


class Migration(migrations.Migration):

    dependencies = [
        ('timetable', '0011_auto_20161015_0914'),
    ]

    operations = [
        migrations.AddField(
            model_name='timetable',
            name='subject_group',
            field=models.CharField(
                verbose_name='Subject group',
                max_length=255,
                default='',
                blank=True),
            preserve_default=True,
        ),
        migrations.RunPython(migrate_subject_type),
    ]
