# coding: utf-8
# pylint: disable=no-init, old-style-class

from django.db import models
from django.utils.translation import ugettext_lazy as _
from djcelery.models import PeriodicTask, PeriodicTasks


class TnxPeriodicTask(PeriodicTask):

    def save(self, *args, **kwargs):
        """Saves periodic task without last_run_at reset"""
        self.exchange = self.exchange or None
        self.routing_key = self.routing_key or None
        self.queue = self.queue or None
        models.Model.save(self, *args, **kwargs)

    class Meta:
        proxy = True


models.signals.pre_delete.connect(PeriodicTasks.changed,
                                  sender=TnxPeriodicTask)
models.signals.pre_save.connect(PeriodicTasks.changed, sender=TnxPeriodicTask)


class TimeTable(models.Model):
    """
    Tionix timetable of tasks.
    """

    TASK_UNKNOWN = 'unknown'
    TASK_SUCCESS = 'success'
    TASK_FAILURE = 'failure'

    task_result_choices = (
        (TASK_SUCCESS, 'SUCCESS'),
        (TASK_FAILURE, 'FAILURE'),
        (TASK_UNKNOWN, 'UNKNOWN')
    )

    author_name = models.CharField(
        _('Task author'), max_length=255, default='')
    tenant_id = models.CharField(
        _('Tenant id'), max_length=64, default='')
    description = models.CharField(
        _('Description'), max_length=255)

    unique_name = models.CharField(
        _('Unique code of task module'), max_length=255)
    periodic_task = models.OneToOneField(TnxPeriodicTask)

    created = models.DateTimeField(auto_now_add=True)

    deleted_at = models.DateTimeField(_('Deleted datetime'), null=True)
    deleted = models.BooleanField(_('Deleted'), default=False)

    repeat = models.BooleanField(
        _('If task repeatable'), default=False)
    subject_id = models.CharField(
        _('Subject ID'), max_length=50, blank=True, null=True)
    subject = models.CharField(
        _('Subject'), max_length=255, default='', blank=True)
    subject_type = models.CharField(
        _('Subject type'), max_length=255, default='', blank=True)
    subject_group = models.CharField(
        _('Subject group'), max_length=255, default='', blank=True)

    begin_date = models.DateField(
        _('Start date for non-cycle tasks'), blank=True, null=True)
    begin_time = models.TimeField(
        _('Start time for non-cycle tasks'), blank=True, null=True)
    timezone = models.CharField(
        _('Timezone'), max_length=255, default='', blank=True)

    last_run_task_id = models.CharField(
        _('Last run task id'), max_length=255, blank=True, null=True)
    last_run_result = models.CharField(
        _('Last run task result'), max_length=255, blank=True, default='',
        choices=task_result_choices)
    last_run_message = models.TextField(
        _('Last run result message'), default='')
    run_count_limit = models.PositiveIntegerField(
        _('Task run count limit'), null=True)

    class Meta:
        verbose_name = _('Timetable of tasks.')
        db_table = 'timetable'
