# coding: utf-8

"""
Service for tasks actions common logic.
"""

import logging
from datetime import datetime

from tionix_scheduler.timetable.models import TimeTable

LOGGER = logging.getLogger(__name__)


class NoTasksFoundError(Exception):
    pass


class TasksActions(object):

    @classmethod
    def delete_timetable(cls, timetable):
        if timetable.periodic_task.enabled:
            timetable.periodic_task.enabled = False
            timetable.periodic_task.save()

        if not timetable.deleted:
            timetable.deleted = True
            timetable.deleted_at = datetime.now()
            timetable.save()

    @classmethod
    def delete_tasks_by_filter(cls, **filter_opts):
        subject_id = filter_opts.get('subject_id')
        subject_type = filter_opts.get('subject_type')

        if not (subject_id and subject_type):
            msg = u'Not specified subject_id and subject_type.'
            LOGGER.error(msg)
            raise ValueError(msg)

        subject_types = subject_type
        if isinstance(subject_type, basestring):
            subject_types = [subject_type]

        _filter = {
            'subject_id': subject_id,
            'subject_type__in': subject_types
        }

        # FIXME get only user tasks
        # pylint: disable=no-member
        timetables = TimeTable.objects.select_related(
            'periodic_task',
            'periodic_task__interval',
            'periodic_task__crontab'
        ).filter(**_filter)

        if timetables:
            for timetable in timetables:
                cls.delete_timetable(timetable)

            LOGGER.info(u'Tasks has been successfully deleted')
        else:
            msg = u'Tasks not found by a given filter.'
            LOGGER.error(msg)
            raise NoTasksFoundError(msg)
